@@ -15,8 +15,8 @@
 // specific language governing permissions and limitations
 // under the License.
 
-use datafusion_expr::logical_plan::Analyze;
-use pyo3::prelude::*;
+use datafusion::logical_expr::logical_plan::Analyze;
+use pyo3::{prelude::*, IntoPyObjectExt};
 use std::fmt::{self, Display, Formatter};
 
 use super::logical_node::LogicalNode;
@@ -69,7 +69,7 @@ impl PyAnalyze {
     }
 
     fn __repr__(&self) -> PyResult<String> {
-        Ok(format!("Analyze({})", self))
+        Ok(format!("Analyze({self})"))
     }
 }
 
@@ -78,7 +78,7 @@ impl LogicalNode for PyAnalyze {
         vec![PyLogicalPlan::from((*self.analyze.input).clone())]
     }
 
-    fn to_variant(&self, py: Python) -> PyResult<PyObject> {
-        Ok(self.clone().into_py(py))
+    fn to_variant<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>> {
+        self.clone().into_bound_py_any(py)
     }
 }
