@@ -15,7 +15,7 @@
 // specific language governing permissions and limitations
 // under the License.
 
-use datafusion_common::Column;
+use datafusion::common::Column;
 use pyo3::prelude::*;
 
 #[pyclass(name = "Column", module = "datafusion.expr", subclass)]
@@ -45,7 +45,7 @@ impl PyColumn {
 
     /// Get the column relation
     fn relation(&self) -> Option<String> {
-        self.col.relation.as_ref().map(|r| format!("{}", r))
+        self.col.relation.as_ref().map(|r| format!("{r}"))
     }
 
     /// Get the fully-qualified column name
